import sys
import pandas as pd
class Dupamb:
    def __init__(self,filename,header=None):
        self.data = pd.read_csv(filename,header=header)
        self.d = self.data.iloc[:,:].values
        self.head = self.d[0,:]
        self.d = self.d[1:,:]
    def removeDupAmb(self,outfilename="out.csv"):
        lst = []
        for i in range(0,len(self.d)):
            st = ""
            for j in range(0,len(self.d[i])):
                st = st + str(self.d[i,j]) + " "
            lst.append(st)
        l = set(lst)
        diction = {}
        for i in l:
            if i[i.index(" "):] in diction.keys():
                if diction[i[i.index(" "):]]!=i[0:i.index(" ")]:
                    diction[i[i.index(" "):]]=-1
            else:
                diction[i[i.index(" "):]]=i[0:i.index(" ")]
        k = []
        for i in diction.keys():
            if diction[i]==-1:
                k.append(i)
        for i in k:
            del(diction[i])
        f = open(outfilename,"w")
        f.write(",".join(self.head)+"\n")
        for i in diction.keys():
            f.write(diction[i]+i.rstrip().replace(" ",",")+"\n")
        f.close()

def interpolation(x,xx,yy):
	s = 0
	for i in range(0,len(xx)):
		p = 1
		for j in range(0,len(xx)):
			if i!=j:
				p*=(((x-xx[j])/(xx[i]-xx[j])))
		s+=(p*(yy[i]))
	return s
if __name__=="__main__":
	try:
		filename = sys.argv[1]
		obj = Dupamb(filename)
		obj.removeDupAmb()
		data = pd.read_csv('out.csv',header=None)
		data = data.iloc[:,:].values
		head = data[0,:]
		data = data[1:,:]
		data = data.astype('float64')
		x = data[:,1:]
		y = data[:,1]
		row = len(x)
		col = len(x[0])
		w = [float(w) for w in sys.argv[3].split(',')]
		k = [float(w) for w in sys.argv[2].split(',')]
		ans = 0
		for i in range(0,col):
			flag = 0
			for j in range(0,row):
				if x[j,i]==k[i]:
					ans+=y[j]*w[i]
					flag = 1
					break
			if flag==0:
				ans+=interpolation(k[i],x[:,i],y*w[i])
		print(ans)
	except:
		print("Exception occurred")


from setuptools import setup

def readme():
  with open('README.md', encoding='utf-8') as f:
    README = f.read()
  return README

setup(
  name="python-interpol",
  version="1.0.1",
  description="A python package to predict target feature using Langranges' Interpolation.",
  long_description=readme(),
  long_description_content_type="text/markdown",
  author="Sahil Ahuja",
  author_email="sahil27ahuja1999@gmail.com",
  license="MIT",
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
  packages=["interpol"],
  include_package_data=True,
  install_requires=[            # I get to this in a second
    'pandas',
  ],
  entry_points={
    "console_scripts": [
      "python-interpol=interpol.interpol:main",    
    ]
  },
)